@@ -22,11 +22,11 @@ import org.gcube.vomanagement.usermanagement.model.GCubeRole;
 import org.gcube.vomanagement.usermanagement.model.GCubeUser;
 import org.gcube.vomanagement.usermanagement.model.MembershipRequestStatus;
 import org.gcube.vomanagement.usermanagement.util.ManagementUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import com.liferay.portal.kernel.exception.PortalException;
 import com.liferay.portal.kernel.exception.SystemException;
+import com.liferay.portal.kernel.log.Log;
+import com.liferay.portal.kernel.log.LogFactoryUtil;
 import com.liferay.portal.kernel.util.DigesterUtil;
 import com.liferay.portal.kernel.util.HttpUtil;
 import com.liferay.portal.model.Contact;
@@ -57,14 +57,13 @@ public class LiferayUserManager implements UserManager {
 	/**
 	 * logger
 	 */
-	private static final Logger _log = LoggerFactory.getLogger(LiferayUserManager.class);
+	private static final Log _log = LogFactoryUtil.getLog(LiferayUserManager.class);
 	/**
 	 * this method sets the Admin privileges in the local thread, needed to perform such operations.
 	 */
 	private void doAsAdmin() {
 		try {			
 			User admin = getAdmin();
-			//_log.debug("Admin found: " + admin.getScreenName());
 			long userId = admin.getUserId();
 			PrincipalThreadLocal.setName(userId);
 			PermissionChecker permissionChecker = PermissionCheckerFactoryUtil.create(UserLocalServiceUtil.getUser(userId));
